@@ -1,4 +1,4 @@
-# Copyright 2016-2020 The Van Valen Lab at the California Institute of
+# Copyright 2016-2021 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -415,7 +415,7 @@ def __create_semantic_head(pyramid_dict,
                            n_dense=128,
                            semantic_id=0,
                            ndim=2,
-                           include_top=False,
+                           include_top=True,
                            target_level=2,
                            upsample_type='upsamplelike',
                            interpolation='bilinear',
